Learn R Programming

preregr (version 0.2.9)

form_preregQE_v0_95: Preregistration Template for Qualitative and Quantitative Ethnographic Studies

Description

A preregistration is a way to design your research project before you begin and to document your decisions, rationale. A template such as this one can be employed to think about what you want to do and how, and subsequently, if you wish, you can submit the finished preregistration to a registry, such as OSF's (https://osf.io/registries/). This template was developed to aid the preregistration of quantitative ethnographic studies, but due to its modular nature, it can be employed for qualitative studies as well.

Usage

form_preregQE_v0_95

Arguments

Format

A (pre)registration form specification